@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2022-2023 Valve Corporation
- * Copyright (C) 2022-2023 LunarG, Inc.
+ * Copyright (C) 2022-2025 Valve Corporation
+ * Copyright (C) 2022-2025 LunarG, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -34,6 +34,9 @@
 #include <fstream>
 #include <mutex>
 #include <sstream>
+#include <optional>
+#include <algorithm>
+#include <limits>
 
 #include "vulkan/vk_layer.h"
 #include "vulkan/vulkan_beta.h"
@@ -61,6 +64,92 @@ inline bool IsFormatSupported(const VkFormatProperties &props) {
     return !(!props.linearTilingFeatures && !props.optimalTilingFeatures && !props.bufferFeatures);
 }
 
+template <typename T>
+struct LimitBase {
+    std::optional<T> limit{};
+
+    // Combines two limit values
+    // - returns true if successful
+    // - returns false if combining is not possible
+    virtual bool Combine(const T &with) = 0;
+
+    // Overrides the target limit value
+    // - returns true if the override is within the target limit
+    //   (e.g. overriding a minimum with a larger minimum)
+    // - returns false if the override is outside the target limit
+    //   (e.g. overriding a minimum with a smaller minimum)
+    virtual bool Override(T &what) const = 0;
+};
+
+template <typename T>
+struct LimitExact final : public LimitBase<T> {
+    bool Combine(const T &with) override {
+        bool result = !LimitBase<T>::limit.has_value() || LimitBase<T>::limit.value() == with;
+        LimitBase<T>::limit = with;
+        return result;
+    }
+
+    bool Override(T &what) const override {
+        bool result = !LimitBase<T>::limit.has_value() || what == LimitBase<T>::limit.value();
+        if (LimitBase<T>::limit.has_value()) what = LimitBase<T>::limit.value();
+        return result;
+    }
+};
+
+template <typename T>
+struct LimitMin final : public LimitBase<T> {
+    bool Combine(const T &with) override {
+        if (LimitBase<T>::limit.has_value()) {
+            LimitBase<T>::limit = std::min(LimitBase<T>::limit.value(), with);
+        } else {
+            LimitBase<T>::limit = with;
+        }
+        return true;
+    }
+
+    bool Override(T &what) const override {
+        bool result = !LimitBase<T>::limit.has_value() || std::min(what, LimitBase<T>::limit.value()) == what;
+        if (LimitBase<T>::limit.has_value()) what = LimitBase<T>::limit.value();
+        return result;
+    }
+};
+
+template <typename T>
+struct LimitMax final : public LimitBase<T> {
+    bool Combine(const T &with) override {
+        if (LimitBase<T>::limit.has_value()) {
+            LimitBase<T>::limit = std::max(LimitBase<T>::limit.value(), with);
+        } else {
+            LimitBase<T>::limit = with;
+        }
+        return true;
+    }
+
+    bool Override(T &what) const override {
+        bool result = !LimitBase<T>::limit.has_value() || std::max(what, LimitBase<T>::limit.value()) == what;
+        if (LimitBase<T>::limit.has_value()) what = LimitBase<T>::limit.value();
+        return result;
+    }
+};
+
+template <typename T>
+struct LimitFlags final : public LimitBase<T> {
+    bool Combine(const T &with) override {
+        if (LimitBase<T>::limit.has_value()) {
+            LimitBase<T>::limit = LimitBase<T>::limit.value() | with;
+        } else {
+            LimitBase<T>::limit = with;
+        }
+        return true;
+    }
+
+    bool Override(T &what) const override {
+        bool result = !LimitBase<T>::limit.has_value() || (what & LimitBase<T>::limit.value()) == LimitBase<T>::limit.value();
+        if (LimitBase<T>::limit.has_value()) what = LimitBase<T>::limit.value();
+        return result;
+    }
+};
+
 typedef std::unordered_map<uint32_t /*VkFormat*/, VkFormatProperties> MapOfVkFormatProperties;
 typedef std::unordered_map<uint32_t /*VkFormat*/, VkFormatProperties3> MapOfVkFormatProperties3;
 typedef std::unordered_map<uint32_t /*VkFormat*/, VkDrmFormatModifierPropertiesList2EXT> MapOfVkDrmFormatModifierProperties;
