@@ -1,6 +1,7 @@
 /*
- * Copyright (c) 2021-2024 Valve Corporation
- * Copyright (c) 2021-2024 LunarG, Inc.
+ * Copyright (c) 2021-2025 Valve Corporation
+ * Copyright (c) 2021-2025 LunarG, Inc.
+ * Copyright (c) 2024 RasterGrid Kft.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -159,10 +160,10 @@ TEST(mocked_api_create_instance, default_extensions) {
     VkInstanceCreateInfo inCreateInfo{ VK_STRUCTURE_TYPE_INSTANCE_CREATE_INFO };
     inCreateInfo.pApplicationInfo = &inAppInfo;
 
-    std::vector<const char*> outExtensions(sizeof(detail::VP_ANDROID_BASELINE_2021::baseline::instanceExtensions) /
-                                           sizeof(detail::VP_ANDROID_BASELINE_2021::baseline::instanceExtensions[0]));
+    std::vector<const char*> outExtensions(sizeof(detail::VP_ANDROID_BASELINE_2021::blocks::baseline::instanceExtensions) /
+                                           sizeof(detail::VP_ANDROID_BASELINE_2021::blocks::baseline::instanceExtensions[0]));
     for (size_t i = 0; i < outExtensions.size(); ++i) {
-        outExtensions[i] = detail::VP_ANDROID_BASELINE_2021::baseline::instanceExtensions[i].extensionName;
+        outExtensions[i] = detail::VP_ANDROID_BASELINE_2021::blocks::baseline::instanceExtensions[i].extensionName;
     }
 
     VkInstanceCreateInfo outCreateInfo = inCreateInfo;
@@ -199,10 +200,10 @@ TEST(mocked_api_create_instance, merge_extensions) {
     inCreateInfo.enabledExtensionCount = static_cast<uint32_t>(inExtensions.size());
     inCreateInfo.ppEnabledExtensionNames = inExtensions.data();
 
-    std::vector<const char*> outExtensions(sizeof(detail::VP_ANDROID_BASELINE_2021::baseline::instanceExtensions) /
-                                           sizeof(detail::VP_ANDROID_BASELINE_2021::baseline::instanceExtensions[0]));
+    std::vector<const char*> outExtensions(sizeof(detail::VP_ANDROID_BASELINE_2021::blocks::baseline::instanceExtensions) /
+                                           sizeof(detail::VP_ANDROID_BASELINE_2021::blocks::baseline::instanceExtensions[0]));
     for (size_t i = 0; i < outExtensions.size(); ++i) {
-        outExtensions[i] = detail::VP_ANDROID_BASELINE_2021::baseline::instanceExtensions[i].extensionName;
+        outExtensions[i] = detail::VP_ANDROID_BASELINE_2021::blocks::baseline::instanceExtensions[i].extensionName;
     }
     outExtensions.push_back(VK_KHR_DISPLAY_EXTENSION_NAME);
 
