@@ -1,6 +1,7 @@
 #!/usr/bin/python3
 #
 # Copyright (c) 2022-2024 LunarG, Inc.
+# Copyright (c) 2024 RasterGrid Kft.
 #
 # Licensed under the Apache License, Version 2.0 (the "License")
 # you may not use this file except in compliance with the License.
@@ -204,6 +205,7 @@ class ProfileMerger():
         merged_properties = dict()
         merged_formats = dict()
         merged_qfp = list()
+        merged_video_profiles = list()
 
         for i in range(len(jsons)):
             self.first = i == 0
@@ -383,6 +385,50 @@ class ProfileMerger():
                     else:
                         print("ERROR: Unknown combination mode: " + self.mode)
 
+                if 'videoProfiles' in capability:
+                    if self.mode == 'intersection':
+                        # If this is the first json just append all video profiles
+                        if self.first:
+                            for video_profile in capability['videoProfiles']:
+                                merged_video_profiles.append(video_profile)
+                        # Otherwise do an intersect
+                        else:
+                            def deep_compare(a, b):
+                                if isinstance(a, list):
+                                    if isinstance(b, list) and len(a) == len(b):
+                                        for i in range(len(a)):
+                                            if not deep_compare(a[i], b[i]):
+                                                return False
+                                        return True
+                                    else:
+                                        return False
+                                elif isinstance(a, dict):
+                                    if isinstance(b, dict) and len(a.keys()) == len(b.keys()):
+                                        for key in a.keys():
+                                            if not key in b or not deep_compare(a[key], b[key]):
+                                                return False
+                                        return True
+                                    else:
+                                        return False
+                                else:
+                                    return a == b
+
+                            for merged_video_profile in list(merged_video_profiles):
+                                found = False
+                                for video_profile in capability['videoProfiles']:
+                                    if deep_compare(merged_video_profile, video_profile):
+                                        found = True
+                                        break
+                                if not found:
+                                    merged_video_profiles.remove(merged_video_profile)
+
+                    elif self.mode == 'union':
+                        for video_profile in capability['videoProfiles']:
+                            merged_video_profiles.append(video_profile)
+
+                    else:
+                        print("ERROR: Unknown combination mode: " + self.mode)
+
         capabilities = dict()
         if merged_extensions:
             sorted_extensions = collections.OrderedDict(sorted(merged_extensions.items()))
@@ -463,6 +509,9 @@ class ProfileMerger():
         if merged_qfp:
             capabilities['queueFamiliesProperties'] = merged_qfp
 
+        if merged_video_profiles:
+            capabilities['videoProfiles'] = merged_video_profiles
+
         return capabilities
 
     def compareList(self, l1, l2):
@@ -575,7 +624,7 @@ class ProfileMerger():
                     continue
 
                 xmlmember = self.registry.structs[property].members[member]
-                if xmlmember.limittype == 'exact' or xmlmember.limittype == 'noauto':
+                if (xmlmember.limittype == 'exact' or xmlmember.limittype == 'noauto') and not xmlmember.isDynamicallySizedArrayWithCap():
                     del merged[member]
                 #elif 'mul'  in xmlmember.limittype and xmlmember.type == 'float':
                 #    del merged[member]
@@ -585,7 +634,7 @@ class ProfileMerger():
                     merged[member] = entry[member]
             elif not member in merged:
                 xmlmember = self.registry.structs[property].members[member]
-                if xmlmember.limittype == 'exact' or xmlmember.limittype == 'noauto':
+                if (xmlmember.limittype == 'exact' or xmlmember.limittype == 'noauto') and not xmlmember.isDynamicallySizedArrayWithCap():
                     continue
                 elif self.mode == 'union' or self.first is True:
                     if xmlmember.type == 'uint64_t' or xmlmember.type == 'VkDeviceSize':
@@ -593,10 +642,6 @@ class ProfileMerger():
                     else:
                         merged[member] = entry[member]
             else:
-                # VK_EXT_host_image_copy is unsupported
-                if property == 'VkPhysicalDeviceHostImageCopyPropertiesEXT':
-                    continue
-
                 # Merge properties
                 xmlmember = self.registry.structs[property].members[member]
                 if xmlmember.limittype == 'struct':
@@ -615,7 +660,7 @@ class ProfileMerger():
                     self.merge_members(merged, member, entry, xmlmember)
 
     def merge_members(self, merged, member, entry, xmlmember):
-        if xmlmember.limittype == 'exact' or xmlmember.limittype == 'noauto':
+        if (xmlmember.limittype == 'exact' or xmlmember.limittype == 'noauto') and not xmlmember.isDynamicallySizedArrayWithCap():
             del merged[member]
         elif self.mode == 'union':
             #if xmlmember.limittype == 'exact':
@@ -632,6 +677,8 @@ class ProfileMerger():
                         merged[member]['width'] = entry[member]['width']
                     if entry[member]['height'] > merged[member]['height']:
                         merged[member]['height'] = entry[member]['height']
+                elif xmlmember.type == 'VkBool32':
+                    merged[member] = merged[member] or entry[member]
                 elif xmlmember.arraySize == 3:
                     if entry[member][0] > merged[member][0]:
                         merged[member][0] = entry[member][0]
@@ -653,6 +700,8 @@ class ProfileMerger():
                         merged[member]['width'] = entry[member]['width']
                     if entry[member]['height'] < merged[member]['height']:
                         merged[member]['height'] = entry[member]['height']
+                elif xmlmember.type == 'VkBool32':
+                    merged[member] = merged[member] and entry[member]
                 elif xmlmember.arraySize == 3:
                     if entry[member][0] < merged[member][0]:
                         merged[member][0] = entry[member][0]
@@ -674,17 +723,16 @@ class ProfileMerger():
                         merged[member] = merged[member] or smember
                     else:
                         merged[member].append(smember)
-            elif xmlmember.limittype == 'not':
-                for smember in entry[member]:
-                    if smember in merged[member]:
-                        merged[member] = (not merged[member]) or (not smember)
-                    else:
-                        merged[member].append(smember)
             elif xmlmember.limittype == 'range':
                 if entry[member][0] < merged[member][0]:
                     merged[member][0] = entry[member][0]
                 if entry[member][1] > merged[member][1]:
                     merged[member][1] = entry[member][1]
+            elif xmlmember.isDynamicallySizedArrayWithCap():
+                entry_set = set(merged[member])
+                merged_set = set(entry[member])
+                union_set = merged_set.union(entry_set)
+                merged[member] = list(union_set)
             else:
                 print("ERROR: Unknown limitype: " + xmlmember.limittype + " for " + member)
         elif self.mode == 'intersection':
@@ -702,6 +750,8 @@ class ProfileMerger():
                         merged[member]['width'] = entry[member]['width']
                     if entry[member]['height'] < merged[member]['height']:
                         merged[member]['height'] = entry[member]['height']
+                elif xmlmember.type == 'VkBool32':
+                    merged[member] = merged[member] and entry[member]
                 elif xmlmember.arraySize == 3:
                     if entry[member][0] < merged[member][0]:
                         merged[member][0] = entry[member][0]
@@ -733,6 +783,8 @@ class ProfileMerger():
                         merged[member]['width'] = entry[member]['width']
                     if entry[member]['height'] < merged[member]['height']:
                         merged[member]['height'] = entry[member]['height']
+                elif xmlmember.type == 'VkBool32':
+                    merged[member] = merged[member] or entry[member]
                 elif xmlmember.arraySize == 3:
                     if entry[member][0] < merged[member][0]:
                         merged[member][0] = entry[member][0]
@@ -759,32 +811,12 @@ class ProfileMerger():
                 else:
                     print("ERROR: '" + member + " 'values with 'min' limittype unknown case.")
             elif xmlmember.limittype == 'bitmask':
-                if xmlmember.type == 'VkBool32':
-                    if member in entry:
-                        merged[member] = merged[member] and entry[member]
-                        if (not merged[member]):
-                            del merged[member]
-                    else:
-                        merged.remove(member)
-                else:
-                    remove_list = []
-                    for value in merged[member]:
-                        if value not in entry[member]:
-                            remove_list.append(value)
-                    for value in remove_list:
-                        merged[member].remove(value)
-            elif xmlmember.limittype == 'not':
-                if xmlmember.type == 'VkBool32':
-                    if member in entry:
-                        merged[member] = merged[member] or entry[member]
-                        if (merged[member]):
-                            del merged[member]
-                    else:
-                        merged.remove(member)
-                else:
-                    for value in merged[member]:
-                        if value not in entry[member]:
-                            merged[member].remove(value)
+                remove_list = []
+                for value in merged[member]:
+                    if value not in entry[member]:
+                        remove_list.append(value)
+                for value in remove_list:
+                    merged[member].remove(value)
             elif xmlmember.limittype == 'range':
                 if entry[member][0] > merged[member][0]:
                     merged[member][0] = entry[member][0]
@@ -792,6 +824,11 @@ class ProfileMerger():
                     merged[member][1] = entry[member][1]
                 #if member[1] < member[0]:
                 #    merged.pop(member, None)
+            elif xmlmember.isDynamicallySizedArrayWithCap():
+                entry_set = set(merged[member])
+                merged_set = set(entry[member])
+                intersection_set = merged_set.intersection(entry_set)
+                merged[member] = list(intersection_set)
             else:
                 print("ERROR: Unknown limitype: " + xmlmember.limittype + " for " + member)
         else:
